//
//  Module      : queuefile.cpp
//  Author      : Oren Sokoler 
//  E-mail      : orenskl@netvision.net.il
//  Description : Implement the queue file class 
//
//  Copyright (C) 1999 Oren Sokoler
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

//-----------------------------------------------------
//                    C header files
//-----------------------------------------------------

#include <string.h>

//-----------------------------------------------------
//                   Qt include files
//-----------------------------------------------------

#include "queuefile.h"

//-----------------------------------------------------
//                      Constants
//-----------------------------------------------------

#define   MAX_LEN    80    // Maximum length of line in queue file

//-----------------------------------------------------
//                 Methods of QueueFile
//-----------------------------------------------------

// Method      : QueueFile
// Description : QueueFile constructor
// Parameters  : Name - Queue file name
// Returns     : none.
// Notes       : none.
QueueFile::QueueFile(const char * Name) : QFile(Name)
{
  char Line[MAX_LEN+1];       // Line buffer


  // Open file
  open(IO_ReadOnly);
  
  memset(Line,0,sizeof(Line));
  // Search for From and To lines
  while (readLine(Line,MAX_LEN) > 0) {
    if (Line[0] == 'S') {
      // This is a From : line get address
      Line[strlen(Line)-1]='\0';
      FromLine = (char *)&Line[1];
    }
    else if (Line[0] == 'R') {
      // This is a To : line get address
      Line[strlen(Line)-1]='\0';
      if (strchr(Line,':'))
	ToLine = (char *)&Line[strchr(Line,':') - Line + 1];
      else
	ToLine = (char *)&Line[1];
    }      
  }

  // Close file
  close();
}

// Method      : ~QueueFile
// Description : QueueFile destructor
// Parameters  : none.
// Returns     : none.
// Notes       : none.  
QueueFile::~QueueFile(void)
{
}

// Method      : From
// Description : Get the from address of this queue file 
// Parameters  : none
// Returns     : From address of this queue file 
// Notes       : none.
const char * QueueFile::From(void) const
{
  return FromLine;
}

// Method      : To
// Description : Get the to address of this queue file 
// Parameters  : none.
// Returns     : To address of this queue file 
// Notes       : none.
const char * QueueFile::To(void) const
{
  return ToLine;
}

